**Example 1: 赎回请求**

赎回请求

Input: 

```
tccli domain CreateDomainRedemption --cli-unfold-argument  \
    --DomainId  domain-dsaklnkl
```

Output: 
```
{
    "Response": {
        "RequestId": "abc"
    }
}
```

